summaryrefslogtreecommitdiffstats
path: root/src/corelib/kernel/qtcore_eval.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/corelib/kernel/qtcore_eval.cpp')
-rw-r--r--src/corelib/kernel/qtcore_eval.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/corelib/kernel/qtcore_eval.cpp b/src/corelib/kernel/qtcore_eval.cpp
index 2ee8c20bc3..0dd0e64977 100644
--- a/src/corelib/kernel/qtcore_eval.cpp
+++ b/src/corelib/kernel/qtcore_eval.cpp
@@ -1,7 +1,7 @@
/****************************************************************************
**
-** Copyright (C) 2015 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
**
** This file is part of the QtCore module of the Qt Toolkit.
**
@@ -10,9 +10,9 @@
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia. For licensing terms and
** conditions see http://qt.digia.com/licensing. For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights. These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** $QT_END_LICENSE$
@@ -47,37 +47,37 @@ QT_BEGIN_NAMESPACE
static const char boilerplate_supported_but_time_limited[] =
"\nQt %1 Evaluation License\n"
- "Copyright (C) 2015 Digia Plc and/or its subsidiary(-ies).\n"
+ "Copyright (C) 2015 The Qt Company Ltd.\n"
"This trial version may only be used for evaluation purposes\n"
"and will shut down after 120 minutes.\n"
"Registered to:\n"
" Licensee: %2\n\n"
"The evaluation expires in %4 days\n\n"
- "Contact http://qt.digia.com/contact-us for pricing and purchasing information.\n";
+ "Contact http://www.qt.io/contact-us for pricing and purchasing information.\n";
static const char boilerplate_supported[] =
"\nQt %1 Evaluation License\n"
- "Copyright (C) 2015 Digia Plc and/or its subsidiary(-ies).\n"
+ "Copyright (C) 2015 The Qt Company Ltd.\n"
"This trial version may only be used for evaluation purposes\n"
"Registered to:\n"
" Licensee: %2\n\n"
"The evaluation expires in %4 days\n\n"
- "Contact http://qt.digia.com/contact-us for pricing and purchasing information.\n";
+ "Contact http://www.qt.io/contact-us for pricing and purchasing information.\n";
static const char boilerplate_expired[] =
"This software is using the trial version of the Qt GUI toolkit.\n"
"The trial period has expired. If you need more time to\n"
"evaluate Qt, or if you have any questions about Qt, contact us\n"
- "at: http://qt.digia.com/contact-us.\n\n";
+ "at: http://www.qt.io/contact-us.\n\n";
static const char will_shutdown_1min[] =
"\nThe evaluation of Qt will SHUT DOWN in 1 minute.\n"
- "Contact http://qt.digia.com/contact-us for pricing and purchasing information.\n";
+ "Contact http://www.qt.io/contact-us for pricing and purchasing information.\n";
static const char will_shutdown_now[] =
"\nThe evaluation of Qt has now reached its automatic\n"
"timeout and will shut down.\n"
- "Contact http://qt.digia.com/contact-us for pricing and purchasing information.\n";
+ "Contact http://www.qt.io/contact-us for pricing and purchasing information.\n";
enum EvaluationStatus {
EvaluationNotSupported = 0,
@@ -10,9 +10,9 @@
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
@@ -23,8 +23,8 @@
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**